<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translation>Informazioni su Tiled</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation type="unfinished">Proprietà</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>&amp;Save map before executing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Droidcraft::DroidcraftPlugin</name>
    <message>
        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
        <source>This is not a valid Droidcraft map file!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+44"/>
        <source>The map needs to have exactly one tile layer!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>The layer must have a size of 48 x 48 tiles!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Impossibile aprire il file in scrittura.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Droidcraft map files (*.dat)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Lua::LuaPlugin</name>
    <message>
        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Impossibile aprire il file in scrittura.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Lua files (*.lua)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation>Tiled</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Recent Files</source>
        <translation>Doc&amp;umenti Recenti</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>Ma&amp;ppa</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation type="obsolete">&amp;Livello</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation>Barra Principale</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>C&amp;opia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>&amp;Informazioni Su Tiled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>Informazioni Su Qt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>&amp;Ridimensiona Mappa...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>&amp;Proprietà Mappa...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;Grid</source>
        <translation>Mostra &amp;Griglia</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>Salva &amp;Come...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;New...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Save As &amp;Image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>&amp;Export As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">Muovi Il Livello In S&amp;u</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation type="obsolete">Ctrl+Maiusc+Su</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">Muovi Il Livello I&amp;n Giù</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation type="obsolete">Ctrl+Maiusc+Giù</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="obsolete">Seleziona T&amp;utto</translation>
    </message>
    <message>
        <source>Select &amp;None</source>
        <translation type="obsolete">Seleziona &amp;Ninente</translation>
    </message>
    <message>
        <source>New...</source>
        <translation type="obsolete">Nuovo...</translation>
    </message>
    <message>
        <location line="-113"/>
        <source>New &amp;Tileset...</source>
        <translation>Nuovo &amp;Insieme Di Celle...</translation>
    </message>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="obsolete">&amp;Rimuovi Livello</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">Aggiungi Livello &amp;Cella...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">Aggiungi Livello &amp;Oggetto...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Layer</source>
        <translation type="obsolete">&amp;Duplica Livello</translation>
    </message>
    <message>
        <source>Ctrl+Shift+D</source>
        <translation type="obsolete">Ctrl+Maiusc+D</translation>
    </message>
    <message>
        <source>Layer &amp;Properties...</source>
        <translation type="obsolete">&amp;Proprietà Livello...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>Zoom Avanti</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>Zoom Indietro</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>Dimensione Originale</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>Save As Image...</source>
        <translation type="obsolete">Salva Come Immagine...</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Cu&amp;t</source>
        <translation>Ta&amp;glia</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>Sp&amp;ostamento Laterale Della Mappa...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>Sposta lateralmente qualsiasi cosa nel livello</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>Pre&amp;ferenze...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>Pulisci La Lista Dei Files Recenti</translation>
    </message>
</context>
<context>
    <name>MapObjectItem</name>
    <message>
        <source>&amp;Duplicate</source>
        <translation type="obsolete">&amp;Duplica</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Rimuovi</translation>
    </message>
    <message>
        <source>&amp;Properties...</source>
        <translation type="obsolete">&amp;Proprietà...</translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
        <source>Not a map file.</source>
        <translation type="unfinished">Questo file non contiene una mappa.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation type="unfinished">Questo file non contiene un insieme di celle.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation type="unfinished">%3 Linea %1, colonna %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation type="unfinished">File non trovato: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation type="unfinished">Impossibile leggere il file: %1</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="unfinished">Orientazione mappa non supportata: &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="unfinished">Parametri non validi per l&apos;insieme di celle &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="unfinished">Errore durante il caricamento dell&apos;insieme di celle &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation type="unfinished">ID non valido per la cella: %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="unfinished">Errore durante il caricamente dell&apos;immagine per l&apos;insieme di celle:
&apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="unfinished">Troppi elementi &lt;tile&gt;</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+72"/>
        <location line="+39"/>
        <location line="+90"/>
        <source>Invalid tile: %1</source>
        <translation type="unfinished">Cella non valida: %1</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Unknown encoding: %1</source>
        <translation type="unfinished">Codifica sconosciuta: %1</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="unfinished">Metodo di compressione &apos;%1&apos; non supportato</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="unfinished">Dati livello corrotti per il livello &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">ID globale cella non valido (inferiore a 0): %1</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile used but no tilesets specified</source>
        <translation type="unfinished">Cella utilizzata ma nessun insieme di celle specificato</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Impossibile aprire il file in scrittura.</translation>
    </message>
</context>
<context>
    <name>NewImageLayerDialog</name>
    <message>
        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
        <source>New Tileset</source>
        <translation type="unfinished">Nuovo Insieme Di Celle</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation type="unfinished">&amp;Nome:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation type="unfinished">Immagine:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation type="unfinished">&amp;Sfoglia...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation type="unfinished">Usa colore trasparente:</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>Nuova Mappa</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>Dimensioni Mappa</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>Grandezza Cella</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>Orientazione:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>Ortogonale</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>Isometrica</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>Nuovo Insieme Di Celle</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation>Insieme Di Celle</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nome:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>Immagine:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Sfoglia...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>Usa colore trasparente:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation>Celle</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>Larghezza cella:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>Margine:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>Altezza cella:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>Spaziatura:</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation type="unfinished">Nome:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation type="unfinished">Tipo:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation type="unfinished">Dimensione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation type="unfinished">Larghezza:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation type="unfinished">Altezza:</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>Spostamento Laterale Mappa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>Spostamento Laterale Dei Contenuti Della Mappa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>Avvolgimento</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>Livelli:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>Tutti I Livelli Visibili</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>Tutti I Livelli</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>Livello Selezionato</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>Limiti:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>Mappa Intera</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>Selezione Corrente</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>Salvataggio e Caricamento</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>&amp;Salva i dati del livello cella come:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation>XML</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (non compresso)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (gzip compresso)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (zlib compresso)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>&amp;Ricarica le immagini dell&apos;insieme di celle quando esse cambiano</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>Non abilitare di default se è noto che un riferimento a un DTD esterno causa problemi con alcuni parametri XML.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>Includi riferimenti &amp;DTD nelle mappe salvate</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>&amp;Lingua:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>Ridimensiona</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Larghezza:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation>Spostamento Laterale</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>Salva Come Immagine</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Sfoglia...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>Settaggi</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>Includi solo livelli &amp;visibili</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>Utilizza l&apos;attuale livello di &amp;zoom</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Impossibile aprire il file in scrittura.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AbstractObjectTool</name>
    <message numerus="yes">
        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
        <location line="+54"/>
        <source>Duplicate %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-53"/>
        <location line="+71"/>
        <source>Remove %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-62"/>
        <location line="+72"/>
        <source>Move %n Object(s) to Layer</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Object &amp;Properties...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+110"/>
        <source>No ruleRegions layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+212"/>
        <source>Tile</source>
        <translation type="unfinished">Cella</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+497"/>
        <source>No set layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Apply AutoMap rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>Strumento Per Riempimento Secchiello</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
        <source>Execute Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Error Executing Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>You do not have any commands setup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Edit Commands...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
        <source>Open in text editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+92"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+101"/>
        <source>Name</source>
        <translation type="unfinished">Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Execute in Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+84"/>
        <source>%1 (copy)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>New command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
        <source>Edit Commands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandProcess</name>
    <message>
        <location filename="../src/tiled/command.cpp" line="+122"/>
        <source>Unable to create/open %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Unable to add executable permissions to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>The command failed to start.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command crashed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command timed out.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>An unknown error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Executing %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+100"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>Gomma</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation>E</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
        <source>Image Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image:</source>
        <translation type="unfinished">Immagine:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Transparent color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Layer Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
        <source>Layers</source>
        <translation>Livelli</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>Opacità:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>Livello</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Proprietà...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
        <location line="+8"/>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location line="-7"/>
        <location line="+6"/>
        <source>Redo</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <source>Error while opening map</source>
        <translation type="obsolete">Errore durante l&apos;apertura della mappa</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>Open Map</source>
        <translation>Apri Mappa</translation>
    </message>
    <message>
        <location line="-13"/>
        <location line="+76"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Files mappa di Tiled (*.tmx)</translation>
    </message>
    <message>
        <source>Error while saving map</source>
        <translation type="obsolete">Errore durante il salvataggio della mappa</translation>
    </message>
    <message>
        <location line="-451"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+1047"/>
        <source>&amp;Layer</source>
        <translation type="unfinished">&amp;Livello</translation>
    </message>
    <message>
        <location line="-910"/>
        <source>Ctrl+PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ctrl+PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Error Opening Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+73"/>
        <location line="+135"/>
        <source>All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-94"/>
        <location line="+141"/>
        <source>Error Saving Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>Modifiche Non Salvate</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>Ci sono modifiche non salvate. Vuoi salvare adesso?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Paste Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+370"/>
        <source>[*]%1 - Tiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-291"/>
        <source>Add External Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+120"/>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>Add Tile Layer</source>
        <translation type="obsolete">Aggiungi Livello Cella</translation>
    </message>
    <message>
        <source>Add Object Layer</source>
        <translation type="obsolete">Aggiungi Livello Oggetto</translation>
    </message>
    <message>
        <source>Layer name:</source>
        <translation type="obsolete">Nome del livello:</translation>
    </message>
    <message>
        <source>New Layer</source>
        <translation type="obsolete">Nuovo Livello</translation>
    </message>
    <message>
        <source>%1[*] - Tiled</source>
        <translation type="obsolete">%1[*] - Tiled</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
        <source>untitled.tmx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Resize Map</source>
        <translation>Ridimensiona Mappa</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset Map</source>
        <translation>Spostamento Laterale Mappa</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Copy of %1</source>
        <translation>Copia di %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>Duplica Livello</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Merge Layer Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Tile</source>
        <translation type="unfinished">Cella</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+126"/>
        <source>Select &amp;All</source>
        <translation type="unfinished">Seleziona T&amp;utto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation type="unfinished">Seleziona &amp;Ninente</translation>
    </message>
    <message>
        <location line="-81"/>
        <source>Ctrl+Shift+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">Aggiungi Livello &amp;Cella...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">Aggiungi Livello &amp;Oggetto...</translation>
    </message>
    <message>
        <location line="+87"/>
        <source>&amp;Duplicate Layer</source>
        <translation type="unfinished">&amp;Duplica Livello</translation>
    </message>
    <message>
        <location line="-79"/>
        <source>Ctrl+Shift+D</source>
        <translation type="unfinished">Ctrl+Maiusc+D</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+Shift+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+48"/>
        <source>&amp;Crop to Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Add &amp;Tile Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Merge Layer Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Layer</source>
        <translation type="unfinished">&amp;Rimuovi Livello</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">Muovi Il Livello In S&amp;u</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Ctrl+Shift+Up</source>
        <translation type="unfinished">Ctrl+Maiusc+Su</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">Muovi Il Livello I&amp;n Giù</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ctrl+Shift+Down</source>
        <translation type="unfinished">Ctrl+Maiusc+Giù</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Select Pre&amp;vious Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;Next Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>R&amp;aise Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Lower Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show/&amp;Hide all Other Layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer &amp;Properties...</source>
        <translation type="unfinished">&amp;Proprietà Livello...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <source>Layer 1</source>
        <translation type="obsolete">Livello 1</translation>
    </message>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>Immagine Insieme Di Celle</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>Livello Oggetto</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>Oggetto</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="obsolete">Nome:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Tipo:</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Change Object</source>
        <translation>Cambia Oggetto</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
        <location line="+110"/>
        <source>Select Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+109"/>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location line="+117"/>
        <source>Move %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>Sistema default</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
        <source>%1 Properties</source>
        <translation>%1 Proprietà</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>Livello</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;nuova proprietà&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>Salva come Immagine</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 gia esistente. Vorresti sovrascriverlo?</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Image</source>
        <translation>Immagine</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>Selezione Rettangolare</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - Rettangolo: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+281"/>
        <source>Stamp Brush</source>
        <translation>Pennello Stampo</translation>
    </message>
    <message>
        <location line="-278"/>
        <location line="+279"/>
        <source>B</source>
        <translation>B</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
        <source>Remove Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Tilesets</source>
        <translation>Insieme Di Celle</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Proprietà...</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
        <source>Tile &amp;Properties...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show &amp;Grid</source>
        <translation type="unfinished">Mostra &amp;Griglia</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Tile</source>
        <translation>Cella</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>Storia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Impossibile aprire il file in scrittura.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <source>XML map reader (*.tmx)</source>
        <translation type="obsolete">Lettore di mappa XML (*.tmx)</translation>
    </message>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">Impossibile aprire il file in scrittura.</translation>
    </message>
    <message>
        <source>XML map writer (*.tmx)</source>
        <translation type="obsolete">Scrittore di mappa XML (*.tmx)</translation>
    </message>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation type="unfinished">Files mappa di Tiled (*.tmx)</translation>
    </message>
</context>
<context>
    <name>TmxReader</name>
    <message>
        <source>Not a map file.</source>
        <translation type="obsolete">Questo file non contiene una mappa.</translation>
    </message>
    <message>
        <source>Not a tileset file.</source>
        <translation type="obsolete">Questo file non contiene un insieme di celle.</translation>
    </message>
    <message>
        <source>%3

Line %1, column %2</source>
        <translation type="obsolete">%3 Linea %1, colonna %2</translation>
    </message>
    <message>
        <source>File not found: %1</source>
        <translation type="obsolete">File non trovato: %1</translation>
    </message>
    <message>
        <source>Unable to read file: %1</source>
        <translation type="obsolete">Impossibile leggere il file: %1</translation>
    </message>
    <message>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="obsolete">Orientazione mappa non supportata: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="obsolete">Parametri non validi per l&apos;insieme di celle &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="obsolete">Errore durante il caricamento dell&apos;insieme di celle &apos;%1&apos;: %2</translation>
    </message>
    <message>
        <source>Invalid tile ID: %1</source>
        <translation type="obsolete">ID non valido per la cella: %1</translation>
    </message>
    <message>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="obsolete">Errore durante il caricamente dell&apos;immagine per l&apos;insieme di celle:
&apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="obsolete">Troppi elementi &lt;tile&gt;</translation>
    </message>
    <message>
        <source>Invalid tile: %1</source>
        <translation type="obsolete">Cella non valida: %1</translation>
    </message>
    <message>
        <source>Unknown encoding: %1</source>
        <translation type="obsolete">Codifica sconosciuta: %1</translation>
    </message>
    <message>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="obsolete">Metodo di compressione &apos;%1&apos; non supportato</translation>
    </message>
    <message>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="obsolete">Dati livello corrotti per il livello &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">ID globale cella non valido (inferiore a 0): %1</translation>
    </message>
    <message>
        <source>Tile used but no tilesets specified</source>
        <translation type="obsolete">Cella utilizzata ma nessun insieme di celle specificato</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
        <source>TMX Viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>Aggiungi Livello</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>Rimuovi Livello</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
        <source>Add Object</source>
        <translation>Aggiungi Oggetto</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Remove Object</source>
        <translation>Rimuovi Oggetto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>Cambia Oggetto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>Cambia Proprietà Livello Oggetto</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>Cambia Proprietà %1 </translation>
    </message>
    <message>
        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>Cambia Selezione</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>Riempi Area</translation>
    </message>
    <message>
        <source>Move Layer Down</source>
        <translation type="obsolete">Muovi Livello Giù</translation>
    </message>
    <message>
        <source>Move Layer Up</source>
        <translation type="obsolete">Muovi livello Su</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>Muovi Oggetto</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>Livello Di Spostamento Laterale</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>Disegna</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>Rinomina Livello</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>Ridimensiona Livello</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>Ridimensiona Mappa</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>Ridimensiona Oggetto</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
        <source>Import Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
        <source>Change Image Layer Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Lower Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Raise Layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>Files Immagine</translation>
    </message>
</context>
</TS>
